<?php
$lang['error_nooptions'] = 'Nessuna opzione specificata per la definizione di campo';
$lang['dropdown'] = 'Men&ugrave; a tendina';
$lang['info_public'] = 'Solo i campi pubblici sono disponibili per la modifica del frontend, o per la visualizzazione nelle viste di sommario o di dettaglio.';
$lang['info_expired_viewable'] = 'Se abilitato, gli articoli scaduti potranno essere visualizzati in modalit&agrave; dettaglio (riproducendo funzionalit&agrave; antecedenti).  Il parametro &quot;showall&quot; pu&ograve; essere utilizzato nell&#039;URL (quando non vengono utilizzati i pretty url) per indicare anche che l&#039;articolo scaduto possa essere visualizzato';
$lang['expired_viewable'] = 'Gli articoli scaduti possono essere visualizzati in modalit&agrave; dettaglio';
$lang['error_insufficientparams'] = 'Parametri insufficienti (o non presenti)';
$lang['error_duplicatename'] = 'Esiste gi&agrave; un elemento con lo stesso nome';
$lang['detail_page'] = 'Pagina Dettagli';
$lang['detail_template'] = 'Modello Dettagli';
$lang['warning_preview'] = 'Attenzione: questo pannello anteprima si comporta in buona parte come la finestra di un browser, permettendovi di navigare rispetto alla pagina iniziale visualizzata. Tuttavia, se lo fate, potreste riscontrare comportamenti inattesi.  Navigare spostandosi dalla pagina iniziale per poi ritornarvi non dur&agrave; i risutati attesi.<br/><strong>Nota:</strong> L&#039;anteprima non carica i file che potreste avere selezionato in attesa di caricamento.';
$lang['article'] = 'Articolo';
$lang['preview'] = 'Anteprima';
$lang['info_detail_returnid'] = 'Questa preferenza &egrave; utilizzata per determinare una pagina (e quindi un template) da usare per visualizzare le pagine di dettaglio. Le URL di Dettaglio News individuali non funzionano se questo parametro non &egrave; impostato su una pagina valida. In aggiunta, se questo parametro &egrave; impostato e nessun parametro detailpage &egrave; aggiunto sul tag news, allora questo valore sar&agrave; usato per i link dei dettagli';
$lang['title_detail_returnid'] = 'Pagina predefinita da usare per la vista dettaglio';
$lang['title_submission_settings'] = 'Impostazioni inserimento News';
$lang['title_fesubmit_settings'] = 'Impostazioni inserimento lato utente';
$lang['title_notification_settings'] = 'Impostazioni di notifica';
$lang['title_detail_settings'] = 'Impostazioni vista dettaglio';
$lang['error_invalidurl'] = 'URL non valido <em>(forse &egrave; gi&agrave; utilizzato o ci sono dei caratteri non validi)</em>';
$lang['url'] = 'URL ';
$lang['expired_searchable'] = 'Gli articoli scaduti possono apparire nei risultati di ricerca';
$lang['helpshowall'] = 'Mostra tutti gli articoli, senza considerare la data di scadenza';
$lang['error_invaliddates'] = 'Una o pi&ugrave; date inserite non sono valide';
$lang['notify_n_draft_items_sub'] = '%d articolo(i) News';
$lang['notify_n_draft_items'] = 'Voi avete %s articolo(i) News che non sono ancora pubblicati';
$lang['unlimited'] = 'Illimitato';
$lang['none'] = 'Nessuno';
$lang['anonymous'] = 'Anonimo';
$lang['unknown'] = 'Sconosciuto';
$lang['fesubmit_redirect'] = 'ID o alias della pagina a cui reindirizzare dopo che un articolo news &egrave; stato inviato tramite azione fesubmit';
$lang['allow_summary_wysiwyg'] = 'Permette di usare un editor WYSIWYG sul campo Sommario';
$lang['title_browsecat_template'] = 'Editor per Modello Elenco Categorie';
$lang['title_browsecat_sysdefault'] = 'Modello predefinito Elenco Categorie';
$lang['browsecattemplate'] = 'Modelli Elenco Categorie';
$lang['error_filesize'] = 'Un file caricato supera la dimensione massima consentita';
$lang['post_date_desc'] = 'Data di pubblicazione discendente';
$lang['post_date_asc'] = 'Data di pubblicazione ascendente';
$lang['expiry_date_desc'] = 'Data di scadenza discendente';
$lang['expiry_date_asc'] = 'Data di scadenza ascendente';
$lang['title_desc'] = 'Titolo discendente';
$lang['title_asc'] = 'Titolo ascendente';
$lang['status_desc'] = 'Stato discendente';
$lang['status_asc'] = 'Stato ascendente';
$lang['fesubmit_status'] = 'Lo stato dell&#039;articolo inviato tramite interfaccia';
$lang['error_invalidfiletype'] = 'Non posso caricare questo tipo di file';
$lang['error_upload'] = 'Problemi nel caricamento di un file';
$lang['error_movefile'] = 'Non posso creare il file: %s';
$lang['error_mkdir'] = 'Non posso creare la cartella: %s';
$lang['expiry_interval'] = 'Il numero di giorni (predefinito) prima che un articolo scada (se la la scadenza &egrave; selezionata)';
$lang['removed'] = 'Rimosso';
$lang['msg_contenttype_removed'] = 'Il tipo di contenuto news &egrave; stato rimosso. Inserite altri tag {news} con parametri appropriati nel vostro modello di pagina o nel contenuto della vostra pagina per  sostituire questa funzionalit&agrave;.';
$lang['delete_selected'] = 'Elimina Articoli Selezionati';
$lang['areyousure_deletemultiple'] = 'Siete certi di volere eliminare tutti questi articoli?\nQuesta azione non &egrave; reversibile!';
$lang['error_templatenamexists'] = 'Esiste gi&agrave; un modello con lo stesso nome';
$lang['error_noarticlesselected'] = 'Nessun articolo selezionato';
$lang['reassign_category'] = 'Cambia la categoria in';
$lang['select'] = 'Seleziona';
$lang['approve'] = 'Imposta lo stato a &#039;Pubblicato&#039;';
$lang['revert'] = 'Imposta lo stato a &#039;Bozza&#039;';
$lang['hide_summary_field'] = 'Nasconde il campo sommario quando aggiungi o modifichi articoli';
$lang['textbox'] = 'Input di Testo';
$lang['checkbox'] = 'Checkbox';
$lang['textarea'] = 'Area di Testo';
$lang['file'] = 'File ';
$lang['auto_create_thumbnails'] = 'Crea automaticamente miniature per i file con queste estensioni';
$lang['allowed_upload_types'] = 'Permettere l&#039;invio solo di file con le seguenti estensioni';
$lang['fielddefupdated'] = 'Definizione del campo aggiornata';
$lang['editfielddef'] = 'Modifica definizione del campo';
$lang['up'] = 'Su';
$lang['down'] = 'Gi&ugrave;';
$lang['fielddefdeleted'] = 'Definizione del campo eliminata';
$lang['nameexists'] = 'Esiste gi&agrave; un campo con questo nome';
$lang['notanumber'] = 'La lunghezza massima non &egrave; un numero';
$lang['fielddef'] = 'Definizione del campo';
$lang['fielddefadded'] = 'Definizione del campo aggiunta con successo';
$lang['public'] = 'Pubblico';
$lang['type'] = 'Tipo';
$lang['info_maxlength'] = 'La lunghezza massima si applica solo a campi di testo.';
$lang['maxlength'] = 'Lunghezza massima';
$lang['addfielddef'] = 'Aggiungere definizione del campo';
$lang['customfields'] = 'Definizioni dei campi';
$lang['deprecated'] = 'non supportato';
$lang['subject_newnews'] = 'Nuovo articolo pubblicato';
$lang['email_subject'] = 'L&#039;Oggetto della email in uscita';
$lang['email_template'] = 'Il formato del messaggio email';
$lang['formsubmit_emailaddress'] = 'Indirizzo email per ricevere notifica di nuovi inserimenti';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Categoria di Caricamento';
$lang['title_available_templates'] = 'Modelli disponibili';
$lang['resettodefault'] = 'Reimposta ai valori predefiniti';
$lang['title_form_template'] = 'Modello del Form Editor';
$lang['title_detail_template'] = 'Editor Modello Dettaglio';
$lang['title_summary_template'] = 'Editor Modello Sommario';
$lang['prompt_templatename'] = 'Nome del Modello';
$lang['prompt_template'] = 'Sorgente del Modello';
$lang['title_form_sysdefault'] = 'Modello Form predefinito';
$lang['title_summary_sysdefault'] = 'Modello Sommario predefinito';
$lang['title_detail_sysdefault'] = 'Modello Dettaglio predefinito';
$lang['info_sysdefault2'] = '<strong>Nota:</strong> Questo pannello contiene aree aree di testo che vi permettono di compilare un insieme di modelli che verranno visualizzati alla creazione di un modello sommario, dettaglio o modulo. Modificare i contenuti di questo pannello <strong>non avr&agrave; effetti sulle visualizzazioni correnti</strong>.';
$lang['info_sysdefault'] = '(contenuto predefinito quando viene creato un movo modello)';
$lang['template'] = 'Modello';
$lang['prompt_name'] = 'Nome';
$lang['prompt_default'] = 'Predefinito';
$lang['prompt_newtemplate'] = 'Crea un nuovo Modello';
$lang['help_pagelimit'] = 'Numero massimo di elementi da visualizzare (per pagina). Se questo parametro non viene inserito verranno visualizzate tutte le ricorrenze. Se viene inserito e ci sono pi&ugrave; elementi disponibili di quelli indicati dal parametro, verranno inseriti testi e collegamenti che permetteranno di scorrere i risultati.';
$lang['prompt_page'] = 'Pagina';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'di';
$lang['prompt_pagelimit'] = 'Limite pagina';
$lang['prompt_sorting'] = 'Ordina per';
$lang['title_filter'] = 'Filtri';
$lang['published'] = 'Pubblicato';
$lang['draft'] = 'Bozza';
$lang['expired'] = 'Scaduto';
$lang['author'] = 'Autore';
$lang['sysdefaults'] = 'Riporta nella configurazione predefinita';
$lang['restoretodefaultsmsg'] = 'Questa operazione riporter&agrave; il contenuto del Modello a quello predefinito. Siete certi di volere procedere?';
$lang['addarticle'] = 'Aggiungi Articolo';
$lang['articleadded'] = 'L&#039;articolo &egrave; stato aggiunto con successo.';
$lang['articleupdated'] = 'L&#039;articolo &egrave; stato aggiornato con successo.';
$lang['articledeleted'] = 'L&#039;articolo &egrave; stato cancellato con successo.';
$lang['addcategory'] = 'Aggiungi Categoria';
$lang['categoryadded'] = 'La categoria &egrave; stata aggiunto con successo.';
$lang['categoryupdated'] = 'La categoria &egrave; stata aggiornata con successo.';
$lang['categorydeleted'] = 'La categoria &egrave; stata cancellata con successo.';
$lang['addnewsitem'] = 'Aggiungi Elemento News';
$lang['allcategories'] = 'Tutte le categorie';
$lang['allentries'] = 'Tutte le news';
$lang['areyousure'] = 'Siete certi di volerlo eliminare?';
$lang['articles'] = 'Articoli';
$lang['cancel'] = 'Annulla';
$lang['category'] = 'Categoria';
$lang['categories'] = 'Categorie';
$lang['default_category'] = 'Categoria predefinita';
$lang['content'] = 'Contenuto';
$lang['dateformat'] = '%s non &egrave; nel formato valido yyyy-mm-dd hh:mm:ss';
$lang['delete'] = 'Elimina';
$lang['description'] = 'Aggiunge, modifica e rimuove News';
$lang['formtemplate'] = 'Modelli Form';
$lang['detailtemplate'] = 'Modelli Dettaglio';
$lang['default_templates'] = 'Modelli Predefiniti';
$lang['detailtemplateupdated'] = 'Il Modello dettaglio aggiornato &egrave; stato salvato nel database correttamente.';
$lang['displaytemplate'] = 'Visualizza Modello';
$lang['edit'] = 'Modifica';
$lang['enddate'] = 'Data Fine';
$lang['endrequiresstart'] = 'Inserire una data di fine richiede anche una data di inizio';
$lang['entries'] = '%s Articoli';
$lang['status'] = 'Stato';
$lang['expiry'] = 'Scadenza';
$lang['filter'] = 'Filtro';
$lang['more'] = 'Continua';
$lang['category_label'] = 'Categoria:';
$lang['author_label'] = 'Inserito da:';
$lang['extra_label'] = 'Extra:';
$lang['moretext'] = 'Altro testo';
$lang['name'] = 'Nome';
$lang['news'] = 'News ';
$lang['news_return'] = 'Torna';
$lang['newcategory'] = 'Nuova categoria';
$lang['needpermission'] = 'E&#039; necessario il permesso &#039;%s&#039; per eseguire di questa funzione.';
$lang['nocategorygiven'] = 'Nessuna Categoria specificata';
$lang['startdatetoolate'] = 'La data di partenza &egrave; troppo in ritardo (dopo la data di fine?)';
$lang['nocontentgiven'] = 'Nessun Contenuto inserito';
$lang['noitemsfound'] = '<strong>Nessun</strong> elemento trovato per la categoria: %s';
$lang['nopostdategiven'] = 'Nessuna data di pubblicazione inserita';
$lang['note'] = '<em>Nota:</em> La data deve essere nel formato: &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Nessun Titolo inserito';
$lang['nonamegiven'] = 'Nessun Nome inserito';
$lang['numbertodisplay'] = 'Numero da visualizzare (se vuoto mostra tutti gli articoli)';
$lang['print'] = 'Stampa';
$lang['postdate'] = 'Data di pubblicazione';
$lang['postinstall'] = 'Assicuratevi di attribuire il permesso &quot;Modifica News&quot; agli utenti che dovranno amministrare le News.';
$lang['selectcategory'] = 'Seleziona la categoria';
$lang['showchildcategories'] = 'Mostra le sottocategorie';
$lang['sortascending'] = 'Ordine crescente';
$lang['startdate'] = 'Data inizio';
$lang['startoffset'] = 'Inizia la visualizzazione dal n-imo articolo';
$lang['startrequiresend'] = 'Inserire una data di inizio richiede anche una data di fine';
$lang['apply'] = 'Applica';
$lang['submit'] = 'Invia';
$lang['summary'] = 'Sommario';
$lang['summarytemplate'] = 'Modelli Sommario';
$lang['summarytemplateupdated'] = 'Il Modello Sommario &egrave; stato aggiornato con successo.';
$lang['title'] = 'Titolo';
$lang['options'] = 'Opzioni';
$lang['optionsupdated'] = 'Le opzioni sono state aggiornate con successo.';
$lang['useexpiration'] = 'Usa la data di scadenza';
$lang['eventdesc-NewsArticleAdded'] = 'Inviato quando un articolo viene aggiunto.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Mandato quando un articolo &egrave; aggiunto.</p>
<h4>Parametri</h4>
<ul>
<li>&quot;news_id&quot; - Id dell&#039;articolo</li>
<li>&quot;category_id&quot; - Id della categoria dell&#039;articolo</li>
<li>&quot;title&quot; - Titolo dell&#039;articolo</li>
<li>&quot;content&quot; - Contenuto dell&#039;articolo</li>
<li>&quot;summary&quot; - Sommario</li>
<li>&quot;status&quot; - Stato dell&#039;articolo (&quot;bozza&quot; or &quot;pubblicato&quot;)</li>
<li>&quot;start_time&quot; - Data in cui l&#039;articolo inizia ad essere visibile</li>
<li>&quot;end_time&quot; - Data in cui l&#039;articolo smette di essere visibile</li>
<li>&quot;useexp&quot; - Se la data di scadenza della visibilit&agrave; deve essere ignorata o meno</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Mandato quando un articolo &egrave; aggiornato.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Mandato quando un articolo &egrave; aggiornato.</p>
<h4>Parametri</h4>
<ul>
<li>&quot;news_id&quot; - Id dell&#039;articolo</li>
<li>&quot;category_id&quot; - Id della categoria dell&#039;articolo</li>
<li>&quot;title&quot; - Titolo dell&#039;articolo</li>
<li>&quot;content&quot; - Contenuto dell&#039;articolo</li>
<li>&quot;summary&quot; - Sommario</li>
<li>&quot;status&quot; - Stato dell&#039;articolo (&quot;bozza&quot; or &quot;pubblicato&quot;)</li>
<li>&quot;start_time&quot; - Data in cui l&#039;articolo inizia ad essere visibile</li>
<li>&quot;end_time&quot; - Data in cui l&#039;articolo smette di essere visibile</li>
<li>&quot;useexp&quot; - Se la data di scadenza della visibilit&agrave; deve essere ignorata o meno</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Mandato quando un articolo &egrave; cancellato.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Mandato quando un articolo &egrave; cancellato.</p>
<h4>Parametri</h4>
<ul>
<li>&quot;news_id&quot; - Id dell&#039;articolo</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Mandato quando una categoria &egrave; aggiunta.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Mandato quando una categoria &egrave; aggiunta.</p>
<h4>Parametri</h4>
<ul>
<li>&quot;category_id&quot; - Id della categoria</li>
<li>&quot;name&quot; - Nome della categoria</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Mandato quando una categoria &egrave; aggiornata.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Mandato quando una categoria &egrave; aggiornata.</p>
<h4>Parametri</h4>
<ul>
<li>&quot;category_id&quot; - Id della categoria</li>
<li>&quot;name&quot; - Nome della categoria</li>
<li>&quot;origname&quot; - Il nome originale della categoria</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Mandato quando una categoria &egrave; cancellata.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Mandato quando una categoria &egrave; cancellata.</p>
<h4>Parameters</h4>
<ul>
<li>&quot;category_id&quot; - Id della categoria</li>
<li>&quot;name&quot; - Nome della categoria cancellata</li>
</ul>
';
$lang['help_articleid'] = 'Questo parametro &egrave; applicabile solo nella visualizzazione dettaglio. Permette di specificare quali articoli visualizzare in modalit&agrave; dettaglio. Se viene usato il valore speciale -1, il sistema visualizzer&agrave; l&#039;articolo pi&ugrave; recente, pubblicato e non scaduto.';
$lang['helpnumber'] = 'Numero massimo di elementi da visualizzare (per pagina) -- se vuoto verranno mostrati tutti gli articoli.';
$lang['helpstart'] = 'Inizia dal n-imo articolo -- se vuoto inizier&agrave; dal primo.';
$lang['helpcategory'] = 'Utilizzato nella vista sommario per mostrare solo elementi di una categoria specifica. <b>Usate * dopo il nome per visualizzare le sottocategorie.</b> E&#039; possibile inserire categorie multiple se separate da virgola. Lasciando vuoto, mostrer&agrave; tutte le categorie.  Questo parametro funziona anche per l&#039;azione &quot;frontend submit&quot;, anche se &egrave; supportato solo l&#039;uso di una categoria.';
$lang['helpmoretext'] = 'Testo da visualizzare alla fine di una news se supera la lunghezza del sommario. Il predefinito &egrave; &quot;Continua&quot;';
$lang['helpsummarytemplate'] = 'Usa un Modello diverso da database per visualizzare il sommario dell&#039;articolo. Questo Modello deve esistere ed essere visibile nel pannello Modelli Sommario dell&#039;area amministrazione del modulo News, ma non &egrave; necessario che sia il predefinito. Se il parametro non viene specificato, verr&agrave; usato il modello predefinito attuale.';
$lang['helpformtemplate'] = 'Usa un Modello da database per visualizzare l&#039;articolo pubblicato. Questo Modello deve esistere ed essere visibile nel Modelli Form della amministrazione anche se non &egrave; quello predefinito. Se il parametro non &egrave; specificato, allora sar&agrave; usato il Modello corrente marcato come predefinito.';
$lang['helpbrowsecattemplate'] = 'Usa un Modello da database per visualizzare le categorie. Questo Modello deve esistere ed essere visibile nei Modelli Categoria della amministrazione anche se non &egrave; quello predefinito. Se il parametro non &egrave; specificato, allora sar&agrave; usato il Modello corrente marcato come predefinito.';
$lang['helpdetailtemplate'] = 'Usa un Modello separato per visualizzare il dettaglio dell&#039;articolo. Questo Modello deve esistere ed essere visibile nel Modello Dettaglio della amministrazione anche se non &egrave; quello predefinito. Se il parametro non &egrave; specificato, allora sar&agrave; usato il Modello corrente marcato come predefinito.';
$lang['helpsortby'] = 'Campo da ordinare per. Le opzioni sono: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;. Predefinito &egrave; &quot;news_date&quot;. Se &egrave; specificato &quot;random&quot; il parametro sortasc &egrave; ignorato.';
$lang['helpsortasc'] = 'Ordina le news in modo ascendente per data piuttosto che discendente.';
$lang['helpdetailpage'] = 'Pagina di visualizzazione del dettaglio della News. Questa pu&ograve; essere una pagina alias o un id. Viene usata per visualizzare il dettaglio in un differente template dal sommario.';
$lang['helpshowarchive'] = 'Mostra solo gli articoli spirati.';
$lang['helpbrowsecat'] = 'Mostra una lista di categorie.';
$lang['helpaction'] = 'Sovrascrive l&#039;azione predefinita. I valori possibili sono:
<ul>
<li>&quot;detail&quot; - per visualizzare un determinato articleid in modalit&agrave; dettaglio</li>
<li>&quot;default&quot; - per visualizzare la modalit&agrave; sommario</li>
<li>&quot;fesubmit&quot; - <strong>Deprecato</strong> per visualizzare il modulo che permette agli utenti l&#039;inserimento di news dal lato utente. Aggiunge il tag <code>{cms_init_editor}</code> nella sezione metadata per inizializzare l&#039;editor wysiwyg selezionato. (Amministrazione del sito >> Impostazioni Globali)</li>
<li>&quot;browsecat&quot; - per visualizzare una lista di categorie navigabile.</li>
</ul>';
$lang['help'] = '<h3>Note Importanti</h3>
<p>Dalla versione 2.9 News ha rimosso il formatpostdate member dai modelli e il parametro dateformat. Per formattare le date dovete usare il modificatore cms_date_format (come indicato nel modello predefinito) ed usare nei Vostri modelli entry->postdate invece di entry->formatpostdate.</p>
<p>Da questa versione &egrave; disabilitata la visualizzazione diretta dei feed RSS. Per gli RSS Feed utilizzare i due moduli (da installare in questo ordine): CGExtensions e CGFeedMaker.</p>
<h3>Che cosa fa?</h3>
<p>News &egrave; un modulo per visualizzare eventi sulla tua pagina, simile allo stile blog, solo con pi&ugrave; funzionalit&agrave;!. Quando il module &egrave; installato, in amministrazione una pagina News &egrave; aggiunta in fondo al menu che vi permette di selezionare o aggiungere una categoria. Quando una categoria &egrave; creata o selezionata, sar&agrave; visualizzata una lista di news per quella categoria. Da qui, potete aggiungere, modificare o cancellare news per quella categoria.</p>
       <h4>Numerous display methods</h4>
	<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
        <h4>Custom Fields</h4>
	<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
        <h4>Categories</h4>
	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
	<h4>Expiry and Status</h4>
	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
	<h3>Sicurezza</h3>
	<p>L&#039;utente deve appartenere a un gruppo con il permesso &#039;Modifica News&#039; per aggiungere, modificare, o cancellare News.</p>
	<p>Per cancellare le news, l&#039;utente deve appartenere a un gruppo con il permesso &#039;Cancella articoli news&#039;</p>
	<p>Per modificare il layout dei Modelli, l&#039;utente deve appartenere a un gruppo con il permesso &#039;Modifica Modelli&#039; </p>
	<p>Per modificare le preferenze globali delle News, l&#039;utente deve appartenere a un gruppo con il permesso &#039;Modifica Preferenze del Sito&#039;</p>
	<p>In aggiunta, per approvare news per la visualizzazione nel frontend l&#039;utente deve appartenere ad un gruppo con il permesso &#039;Approva News&#039;.</p>
	<h3>Come usarlo?</h3>
	<p>Il modo pi&ugrave; semplice di usarlo &egrave; con il tag {news} (il modulo in un tag, per semplificare la sintassi). Inseririsci il modulo dove vuoi nel vostro Modello o pagina, questo visualizzer&agrave; le news. Esempio di sintassi: <code>{news number=&#039;5&#039;}</code></p>
<h3>Modelli</h3>
	<p>Dalla versione 2.3 News supporta modelli multipli da database e NON supporta pi&ugrave; i modelli file. Utenti che usano il vecchio sistema dei modelli file DEVONO seguire questi passi (per ciascun modello):
<ul>
<li>Copia il modello file negli appunti</li>
<li>Crea un nuovo Modello database <em>(di sommario o dettaglio come richiesto)</em>. Dare al nuovo modello lo stesso nome (incluso l&#039;estensione .tpl) esattamente del vecchio file e incollare il contenuto.</li>
<li>Premere Invio</li>
</ul>
Seguendo questi passi si dovrebbe risolvere il problema dei nuovi modelli non trovati e altri errori similari di smarty quando aggiorni ad una versione di CMS che contiene News 2.3 o maggiore.</p>';
$lang['utma'] = '156861353.1075351023.1379535264.1379535264.1379535264.1';
$lang['utmz'] = '156861353.1379535264.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/list_tagged/admin|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>